@@ -34,7 +34,7 @@ class ldapFun(cl_profile._error):
         try:
             self.conLdap = self.__ldapConnect(dnUser, password, host)
         except ldap.LDAPError as e:
-            self.setError(str(e))
+            self.setError(e.args[0]['desc'])
 
     def __ldapConnect(self, dnUser, password, host):
         """Соединение с LDAP сервером"""
